__version__ = "0.1.48"
__git_commiter_name__ = "Arnon Yaari"
__git_commiter_email__ = "arnony@infinidat.com"
__git_branch__ = '(Not currently on any branch)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = '2f036f5d662a8694651a83bb6083bd9557821968'
__git_head_subject__ = 'Finished release v0.1.48.'
__git_head_message__ = ''
__git_dirty_diff__ = ''